//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraArgs](index.md)/[agari](agari.md)

# agari

[common]\
val [agari](agari.md): [Tile](../../mahjongutils.models/-tile/index.md)

#### Parameters

common

| | |
|---|---|
| agari | 和牌张 |
